You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by rh...@apache.org on 2010/06/28 14:45:40 UTC

svn commit: r958559 - in /subversion/trunk/subversion: include/ libsvn_client/ libsvn_delta/ libsvn_subr/ libsvn_wc/ mod_dav_svn/ svn/ tests/libsvn_subr/

Author: rhuijben
Date: Mon Jun 28 12:45:39 2010
New Revision: 958559

URL: http://svn.apache.org/viewvc?rev=958559&view=rev
Log:
Switch the argument order of (the new in 1.7) svn_dirent_split(),
svn_uri_split() and svn_relpath_split() functions to our new standard
order: output arguments before input arguments.

* subversion/include/svn_dirent_uri.h
  (svn_dirent_split, svn_relpath_split, svn_uri_split): Reorder arguments.

* subversion/libsvn_client/add.c
* subversion/libsvn_client/commit.c
* subversion/libsvn_client/copy.c
* subversion/libsvn_client/delete.c
* subversion/libsvn_client/diff.c
* subversion/libsvn_client/externals.c
* subversion/libsvn_client/info.c
* subversion/libsvn_client/list.c
* subversion/libsvn_client/locking_commands.c
* subversion/libsvn_client/update.c
* subversion/libsvn_delta/path_driver.c
* subversion/libsvn_subr/dirent_uri.c
* subversion/libsvn_wc/adm_crawler.c
* subversion/libsvn_wc/adm_files.c
* subversion/libsvn_wc/adm_ops.c
* subversion/libsvn_wc/copy.c
* subversion/libsvn_wc/diff.c
* subversion/libsvn_wc/entries.c
* subversion/libsvn_wc/lock.c
* subversion/libsvn_wc/merge.c
* subversion/libsvn_wc/node.c
* subversion/libsvn_wc/old-and-busted.c
* subversion/libsvn_wc/props.c
* subversion/libsvn_wc/update_editor.c
* subversion/libsvn_wc/wc_db.c
* subversion/libsvn_wc/wc_db_pdh.c
* subversion/mod_dav_svn/repos.c
* subversion/svn/util.c
* subversion/tests/libsvn_subr/dirent_uri-test.c
  (*): Update callers.

Modified:
    subversion/trunk/subversion/include/svn_dirent_uri.h
    subversion/trunk/subversion/libsvn_client/add.c
    subversion/trunk/subversion/libsvn_client/commit.c
    subversion/trunk/subversion/libsvn_client/copy.c
    subversion/trunk/subversion/libsvn_client/delete.c
    subversion/trunk/subversion/libsvn_client/diff.c
    subversion/trunk/subversion/libsvn_client/externals.c
    subversion/trunk/subversion/libsvn_client/info.c
    subversion/trunk/subversion/libsvn_client/list.c
    subversion/trunk/subversion/libsvn_client/locking_commands.c
    subversion/trunk/subversion/libsvn_client/update.c
    subversion/trunk/subversion/libsvn_delta/path_driver.c
    subversion/trunk/subversion/libsvn_subr/dirent_uri.c
    subversion/trunk/subversion/libsvn_wc/adm_crawler.c
    subversion/trunk/subversion/libsvn_wc/adm_files.c
    subversion/trunk/subversion/libsvn_wc/adm_ops.c
    subversion/trunk/subversion/libsvn_wc/copy.c
    subversion/trunk/subversion/libsvn_wc/diff.c
    subversion/trunk/subversion/libsvn_wc/entries.c
    subversion/trunk/subversion/libsvn_wc/lock.c
    subversion/trunk/subversion/libsvn_wc/merge.c
    subversion/trunk/subversion/libsvn_wc/node.c
    subversion/trunk/subversion/libsvn_wc/old-and-busted.c
    subversion/trunk/subversion/libsvn_wc/props.c
    subversion/trunk/subversion/libsvn_wc/update_editor.c
    subversion/trunk/subversion/libsvn_wc/wc_db.c
    subversion/trunk/subversion/libsvn_wc/wc_db_pdh.c
    subversion/trunk/subversion/mod_dav_svn/repos.c
    subversion/trunk/subversion/svn/util.c
    subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c

Modified: subversion/trunk/subversion/include/svn_dirent_uri.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_dirent_uri.h?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_dirent_uri.h (original)
+++ subversion/trunk/subversion/include/svn_dirent_uri.h Mon Jun 28 12:45:39 2010
@@ -256,9 +256,9 @@ svn_dirent_dirname(const char *dirent,
  * @since New in 1.7.
  */
 void
-svn_dirent_split(const char *dirent,
-                 const char **dirpath,
+svn_dirent_split(const char **dirpath,
                  const char **base_name,
+                 const char *dirent,
                  apr_pool_t *pool);
 
 /** Divide the canonicalized @a relpath into @a *dirpath and @a
@@ -280,9 +280,9 @@ svn_dirent_split(const char *dirent,
  * @since New in 1.7.
  */
 void
-svn_relpath_split(const char *relpath,
-                  const char **dirpath,
+svn_relpath_split(const char **dirpath,
                   const char **base_name,
+                  const char *relpath,
                   apr_pool_t *pool);
 
 /** Get the basename of the specified canonicalized @a relpath.  The
@@ -338,9 +338,9 @@ svn_relpath_dirname(const char *relpath,
  * @since New in 1.7.
  */
 void
-svn_uri_split(const char *dirent,
-              const char **dirpath,
+svn_uri_split(const char **dirpath,
               const char **base_name,
+              const char *uri,
               apr_pool_t *pool);
 
 /** Get the basename of the specified canonicalized @a uri.  The

Modified: subversion/trunk/subversion/libsvn_client/add.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/add.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/add.c (original)
+++ subversion/trunk/subversion/libsvn_client/add.c Mon Jun 28 12:45:39 2010
@@ -734,7 +734,7 @@ mkdir_urls(svn_commit_info_t **commit_in
   if (! targets->nelts)
     {
       const char *bname;
-      svn_uri_split(common, &common, &bname, pool);
+      svn_uri_split(&common, &bname, common, pool);
       APR_ARRAY_PUSH(targets, const char *) = bname;
     }
   else
@@ -756,7 +756,7 @@ mkdir_urls(svn_commit_info_t **commit_in
       if (resplit)
         {
           const char *bname;
-          svn_uri_split(common, &common, &bname, pool);
+          svn_uri_split(&common, &bname, common, pool);
           for (i = 0; i < targets->nelts; i++)
             {
               const char *path = APR_ARRAY_IDX(targets, i, const char *);

Modified: subversion/trunk/subversion/libsvn_client/commit.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/commit.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/commit.c (original)
+++ subversion/trunk/subversion/libsvn_client/commit.c Mon Jun 28 12:45:39 2010
@@ -728,7 +728,7 @@ svn_client_import3(svn_commit_info_t **c
           else
             svn_error_clear(err);
 
-          svn_uri_split(url, &temp, &dir, pool);
+          svn_uri_split(&temp, &dir, url, pool);
           APR_ARRAY_PUSH(new_entries, const char *) =
             svn_path_uri_decode(dir, pool);
           url = temp;

Modified: subversion/trunk/subversion/libsvn_client/copy.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/copy.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/copy.c (original)
+++ subversion/trunk/subversion/libsvn_client/copy.c Mon Jun 28 12:45:39 2010
@@ -483,8 +483,8 @@ wc_to_wc_copy(const apr_array_header_t *
           _("Path '%s' already exists"),
           svn_dirent_local_style(pair->dst_abspath_or_url, pool));
 
-      svn_dirent_split(pair->dst_abspath_or_url, &pair->dst_parent_abspath,
-                       &pair->base_name, pool);
+      svn_dirent_split(&pair->dst_parent_abspath, &pair->base_name,
+                       pair->dst_abspath_or_url, pool);
 
       /* Make sure the destination parent is a directory and produce a clear
          error message if it is not. */
@@ -703,7 +703,7 @@ find_absent_parents2(svn_ra_session_t *r
   while (kind == svn_node_none)
     {
       APR_ARRAY_PUSH(new_dirs, const char *) = root_url;
-      svn_uri_split(root_url, &root_url, NULL, pool);
+      root_url = svn_uri_dirname(root_url, pool);
 
       SVN_ERR(svn_ra_reparent(ra_session, root_url, pool));
       SVN_ERR(svn_ra_check_path(ra_session, "", SVN_INVALID_REVNUM, &kind,
@@ -1205,7 +1205,7 @@ wc_to_repos_copy(svn_commit_info_t **com
    *     It looks like the entire block of code hanging off this comment
    *     is redundant. */
   first_pair = APR_ARRAY_IDX(copy_pairs, 0, svn_client__copy_pair_t *);
-  svn_uri_split(first_pair->dst_abspath_or_url, &top_dst_url, NULL, pool);
+  top_dst_url = svn_uri_dirname(first_pair->dst_abspath_or_url, pool);
   for (i = 1; i < copy_pairs->nelts; i++)
     {
       svn_client__copy_pair_t *pair = APR_ARRAY_IDX(copy_pairs, i,

Modified: subversion/trunk/subversion/libsvn_client/delete.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/delete.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/delete.c (original)
+++ subversion/trunk/subversion/libsvn_client/delete.c Mon Jun 28 12:45:39 2010
@@ -161,7 +161,7 @@ delete_urls(svn_commit_info_t **commit_i
   if (! targets->nelts)
     {
       const char *bname;
-      svn_uri_split(common, &common, &bname, pool);
+      svn_uri_split(&common, &bname, common, pool);
       APR_ARRAY_PUSH(targets, const char *) = svn_path_uri_decode(bname, pool);
     }
 

Modified: subversion/trunk/subversion/libsvn_client/diff.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/diff.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/diff.c (original)
+++ subversion/trunk/subversion/libsvn_client/diff.c Mon Jun 28 12:45:39 2010
@@ -1270,9 +1270,9 @@ diff_prepare_repos_repos(const struct di
   drr->target2 = "";
   if ((kind1 == svn_node_file) || (kind2 == svn_node_file))
     {
-      svn_uri_split(drr->url1, &drr->anchor1, &drr->target1, pool);
+      svn_uri_split(&drr->anchor1, &drr->target1, drr->url1, pool);
       drr->target1 = svn_path_uri_decode(drr->target1, pool);
-      svn_uri_split(drr->url2, &drr->anchor2, &drr->target2, pool);
+      svn_uri_split(&drr->anchor2, &drr->target2, drr->url2, pool);
       drr->target2 = svn_path_uri_decode(drr->target2, pool);
       if (drr->base_path)
         drr->base_path = svn_dirent_dirname(drr->base_path, pool);

Modified: subversion/trunk/subversion/libsvn_client/externals.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/externals.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/externals.c (original)
+++ subversion/trunk/subversion/libsvn_client/externals.c Mon Jun 28 12:45:39 2010
@@ -116,7 +116,7 @@ relegate_dir_external(void *baton,
       svn_error_clear(err);
       err = SVN_NO_ERROR;
 
-      svn_dirent_split(b->local_abspath, &parent_dir, &dirname, scratch_pool);
+      svn_dirent_split(&parent_dir, &dirname, b->local_abspath, scratch_pool);
 
       /* Reserve the new dir name. */
       SVN_ERR(svn_io_open_uniquely_named(NULL, &new_path,

Modified: subversion/trunk/subversion/libsvn_client/info.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/info.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/info.c (original)
+++ subversion/trunk/subversion/libsvn_client/info.c Mon Jun 28 12:45:39 2010
@@ -527,7 +527,7 @@ svn_client_info3(const char *abspath_or_
   SVN_ERR(svn_ra_get_repos_root2(ra_session, &repos_root_URL, pool));
   SVN_ERR(svn_ra_get_uuid2(ra_session, &repos_UUID, pool));
 
-  svn_uri_split(url, &parent_url, &base_name, pool);
+  svn_uri_split(&parent_url, &base_name, url, pool);
   base_name = svn_path_uri_decode(base_name, pool);
 
   /* Get the dirent for the URL itself. */

Modified: subversion/trunk/subversion/libsvn_client/list.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/list.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/list.c (original)
+++ subversion/trunk/subversion/libsvn_client/list.c Mon Jun 28 12:45:39 2010
@@ -170,7 +170,7 @@ svn_client_list2(const char *path_or_url
 
               /* Open another session to the path's parent.  This server
                  doesn't support svn_ra_reparent anyway, so don't try it. */
-              svn_uri_split(url, &parent_url, &base_name, pool);
+              svn_uri_split(&parent_url, &base_name, url, pool);
 
               /* 'base_name' is now the last component of an URL, but we want
                  to use it as a plain file name. Therefore, we must URI-decode

Modified: subversion/trunk/subversion/libsvn_client/locking_commands.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/locking_commands.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/locking_commands.c (original)
+++ subversion/trunk/subversion/libsvn_client/locking_commands.c Mon Jun 28 12:45:39 2010
@@ -206,9 +206,9 @@ organize_lock_targets(const char **commo
     {
       const char *parent, *base;
       if (url_mode)
-        svn_uri_split(*common_parent_url, &parent, &base, pool);
+        svn_uri_split(&parent, &base, *common_parent_url, pool);
       else
-        svn_dirent_split(*common_parent_url, &parent, &base, pool);
+        svn_dirent_split(&parent, &base, *common_parent_url, pool);
 
       *common_parent_url = parent;
       APR_ARRAY_PUSH(rel_targets, const char *) = base;

Modified: subversion/trunk/subversion/libsvn_client/update.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/update.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/update.c (original)
+++ subversion/trunk/subversion/libsvn_client/update.c Mon Jun 28 12:45:39 2010
@@ -70,7 +70,7 @@ file_fetcher(void *baton,
   struct ff_baton *ffb = (struct ff_baton *)baton;
   const char *dirpath, *base_name, *session_url, *old_session_url;
 
-  svn_relpath_split(path, &dirpath, &base_name, pool);
+  svn_relpath_split(&dirpath, &base_name, path, pool);
   session_url = svn_path_url_add_component2(ffb->repos_root, 
                                             dirpath, pool);
 

Modified: subversion/trunk/subversion/libsvn_delta/path_driver.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_delta/path_driver.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_delta/path_driver.c (original)
+++ subversion/trunk/subversion/libsvn_delta/path_driver.c Mon Jun 28 12:45:39 2010
@@ -215,9 +215,9 @@ svn_delta_path_driver(const svn_delta_ed
       /*** Step C - Open any directories between the common ancestor
            and the parent of the current path. ***/
       if (*path == '/')
-        svn_uri_split(path, &pdir, &bname, iterpool);
+        svn_uri_split(&pdir, &bname, path, iterpool);
       else
-        svn_relpath_split(path, &pdir, &bname, iterpool);
+        svn_relpath_split(&pdir, &bname, path, iterpool);
       if (strlen(pdir) > common_len)
         {
           const char *piece = pdir + common_len + 1;

Modified: subversion/trunk/subversion/libsvn_subr/dirent_uri.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_subr/dirent_uri.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_subr/dirent_uri.c (original)
+++ subversion/trunk/subversion/libsvn_subr/dirent_uri.c Mon Jun 28 12:45:39 2010
@@ -1293,9 +1293,9 @@ svn_dirent_basename(const char *dirent, 
 }
 
 void
-svn_dirent_split(const char *dirent,
-                 const char **dirpath,
+svn_dirent_split(const char **dirpath,
                  const char **base_name,
+                 const char *dirent,
                  apr_pool_t *pool)
 {
   assert(dirpath != base_name);
@@ -1339,9 +1339,9 @@ svn_relpath_basename(const char *relpath
 }
 
 void
-svn_relpath_split(const char *relpath,
-                  const char **dirpath,
+svn_relpath_split(const char **dirpath,
                   const char **base_name,
+                  const char *relpath,
                   apr_pool_t *pool)
 {
   assert(dirpath != base_name);
@@ -1390,9 +1390,9 @@ svn_uri_basename(const char *uri, apr_po
 }
 
 void
-svn_uri_split(const char *uri,
-              const char **dirpath,
+svn_uri_split(const char **dirpath,
               const char **base_name,
+              const char *uri,
               apr_pool_t *pool)
 {
   assert(dirpath != base_name);

Modified: subversion/trunk/subversion/libsvn_wc/adm_crawler.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/adm_crawler.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/adm_crawler.c (original)
+++ subversion/trunk/subversion/libsvn_wc/adm_crawler.c Mon Jun 28 12:45:39 2010
@@ -928,7 +928,7 @@ svn_wc_crawl_revisions5(svn_wc_context_t
       svn_wc__db_status_t parent_status;
       const char *parent_repos_relpath;
 
-      svn_dirent_split(local_abspath, &parent_abspath, &base,
+      svn_dirent_split(&parent_abspath, &base, local_abspath,
                        scratch_pool);
 
       /* We can assume a file is in the same repository as its parent

Modified: subversion/trunk/subversion/libsvn_wc/adm_files.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/adm_files.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/adm_files.c (original)
+++ subversion/trunk/subversion/libsvn_wc/adm_files.c Mon Jun 28 12:45:39 2010
@@ -217,7 +217,7 @@ svn_wc__text_base_path(const char **resu
 
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath));
 
-  svn_dirent_split(local_abspath, &newpath, &base_name, pool);
+  svn_dirent_split(&newpath, &base_name, local_abspath, pool);
   *result_abspath = simple_extend(newpath,
                                   FALSE,
                                   SVN_WC__ADM_TEXT_BASE,
@@ -239,7 +239,7 @@ svn_wc__text_base_deterministic_tmp_path
 
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath));
 
-  svn_dirent_split(local_abspath, &newpath, &base_name, pool);
+  svn_dirent_split(&newpath, &base_name, local_abspath, pool);
   *result_abspath = simple_extend(newpath, TRUE, SVN_WC__ADM_TEXT_BASE,
                                   base_name, SVN_WC__BASE_EXT, pool);
 
@@ -257,7 +257,7 @@ svn_wc__text_revert_path(const char **re
 
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath));
 
-  svn_dirent_split(local_abspath, &newpath, &base_name, pool);
+  svn_dirent_split(&newpath, &base_name, local_abspath, pool);
   *result_abspath = simple_extend(newpath,
                                   FALSE,
                                   SVN_WC__ADM_TEXT_BASE,
@@ -669,7 +669,7 @@ svn_wc__prop_path(const char **prop_path
 
       const char *base_name;
 
-      svn_dirent_split(path, prop_path, &base_name, pool);
+      svn_dirent_split(prop_path, &base_name, path, pool);
       *prop_path = simple_extend(*prop_path, FALSE, dirs[props_kind],
                                  base_name, extensions[props_kind], pool);
     }

Modified: subversion/trunk/subversion/libsvn_wc/adm_ops.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/adm_ops.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/adm_ops.c (original)
+++ subversion/trunk/subversion/libsvn_wc/adm_ops.c Mon Jun 28 12:45:39 2010
@@ -1127,7 +1127,7 @@ svn_wc_add4(svn_wc_context_t *wc_ctx,
                                                         scratch_pool)
                                    && SVN_IS_VALID_REVNUM(copyfrom_rev)));
 
-  svn_dirent_split(local_abspath, &parent_abspath, &base_name, scratch_pool);
+  svn_dirent_split(&parent_abspath, &base_name, local_abspath, scratch_pool);
   if (svn_wc_is_adm_dir(base_name, scratch_pool))
     return svn_error_createf
       (SVN_ERR_ENTRY_FORBIDDEN, NULL,
@@ -1540,7 +1540,7 @@ svn_wc_register_file_external(svn_wc_con
   svn_wc__db_t *db = wc_ctx->db;
   const char *parent_abspath, *base_name, *repos_root_url;
 
-  svn_dirent_split(local_abspath, &parent_abspath, &base_name, scratch_pool);
+  svn_dirent_split(&parent_abspath, &base_name, local_abspath, scratch_pool);
 
   SVN_ERR(svn_wc_add4(wc_ctx, local_abspath, svn_depth_infinity,
                       NULL, SVN_INVALID_REVNUM, NULL, NULL, NULL, NULL,

Modified: subversion/trunk/subversion/libsvn_wc/copy.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/copy.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/copy.c (original)
+++ subversion/trunk/subversion/libsvn_wc/copy.c Mon Jun 28 12:45:39 2010
@@ -372,7 +372,7 @@ copy_versioned_dir(svn_wc_context_t *wc_
           svn_depth_t depth;
           svn_wc__db_status_t status;
 
-          svn_dirent_split(dst_abspath, &dst_parent_abspath, &name,
+          svn_dirent_split(&dst_parent_abspath, &name, dst_abspath,
                            scratch_pool);
           SVN_ERR(svn_wc__node_get_url(&parent_url, wc_ctx, dst_parent_abspath,
                                        scratch_pool, scratch_pool));
@@ -604,7 +604,7 @@ svn_wc_copy3(svn_wc_context_t *wc_ctx,
   svn_wc__db_kind_t kind;
   const char *dstdir_abspath, *dst_basename;
 
-  svn_dirent_split(dst_abspath, &dstdir_abspath, &dst_basename, scratch_pool);
+  svn_dirent_split(&dstdir_abspath, &dst_basename, dst_abspath, scratch_pool);
 
   SVN_ERR(svn_wc__get_entry_versioned(&dst_entry, wc_ctx->db, dstdir_abspath,
                                       svn_node_dir, FALSE, FALSE,

Modified: subversion/trunk/subversion/libsvn_wc/diff.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/diff.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/diff.c (original)
+++ subversion/trunk/subversion/libsvn_wc/diff.c Mon Jun 28 12:45:39 2010
@@ -1535,7 +1535,7 @@ apply_textdelta(void *file_baton,
                                      NULL, NULL, NULL, eb->db,
                                      fb->local_abspath, pool, pool));
 
-  svn_dirent_split(fb->wc_path, &parent, &base_name, fb->pool);
+  svn_dirent_split(&parent, &base_name, fb->wc_path, fb->pool);
 
   /* If the node is added-with-history, then this is not actually
      an add, but a modification. */
@@ -1935,7 +1935,7 @@ svn_wc_diff6(svn_wc_context_t *wc_ctx,
       target = "";
     }
   else
-    svn_dirent_split(target_path, &anchor_path, &target, pool);
+    svn_dirent_split(&anchor_path, &target, target_path, pool);
 
   SVN_ERR(make_edit_baton(&eb,
                           wc_ctx->db,

Modified: subversion/trunk/subversion/libsvn_wc/entries.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/entries.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/entries.c (original)
+++ subversion/trunk/subversion/libsvn_wc/entries.c Mon Jun 28 12:45:39 2010
@@ -1390,7 +1390,7 @@ get_entry_access_info(const char **adm_a
       /* FILE node needs to read the parent directory. Or a DIR node
          needs to read from the parent to get at the stub entry. Or this
          is an UNKNOWN node, and we need to examine the parent.  */
-      svn_dirent_split(local_abspath, adm_abspath, entry_name, result_pool);
+      svn_dirent_split(adm_abspath, entry_name, local_abspath, result_pool);
     }
 
   return SVN_NO_ERROR;

Modified: subversion/trunk/subversion/libsvn_wc/lock.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/lock.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/lock.c (original)
+++ subversion/trunk/subversion/libsvn_wc/lock.c Mon Jun 28 12:45:39 2010
@@ -1043,7 +1043,7 @@ child_is_disjoint(svn_boolean_t *disjoin
   svn_boolean_t found_in_parent = FALSE;
   int i;
 
-  svn_dirent_split(local_abspath, &parent_abspath, &base, scratch_pool);
+  svn_dirent_split(&parent_abspath, &base, local_abspath, scratch_pool);
 
   /* Check if the parent directory knows about this node */
   err = svn_wc__db_read_children(&children, db, parent_abspath, scratch_pool,

Modified: subversion/trunk/subversion/libsvn_wc/merge.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/merge.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/merge.c (original)
+++ subversion/trunk/subversion/libsvn_wc/merge.c Mon Jun 28 12:45:39 2010
@@ -427,7 +427,7 @@ save_merge_result(svn_skel_t **work_item
   const char *dir_abspath;
   const char *filename;
 
-  svn_dirent_split(versioned_abspath, &dir_abspath, &filename,
+  svn_dirent_split(&dir_abspath, &filename, versioned_abspath,
                    scratch_pool);
 
   /* ### Should use preserved-conflict-file-exts. */
@@ -646,7 +646,7 @@ preserve_pre_merge_files(svn_skel_t **wo
 
   *work_items = NULL;
 
-  svn_dirent_split(target_abspath, &dir_abspath, &target_name, scratch_pool);
+  svn_dirent_split(&dir_abspath, &target_name, target_abspath, scratch_pool);
   SVN_ERR(svn_wc__db_temp_wcroot_tempdir(&temp_dir, db, target_abspath,
                                          scratch_pool, scratch_pool));
 
@@ -902,7 +902,7 @@ merge_text_file(svn_skel_t **work_items,
 
   *work_items = NULL;
 
-  svn_dirent_split(target_abspath, &dir_abspath, &base_name, pool);
+  svn_dirent_split(&dir_abspath, &base_name, target_abspath, pool);
 
   /* Open a second temporary file for writing; this is where diff3
      will write the merged results.  We want to use a tempfile
@@ -1072,7 +1072,7 @@ merge_binary_file(svn_skel_t **work_item
 
   *work_items = NULL;
 
-  svn_dirent_split(target_abspath, &merge_dirpath, &merge_filename, pool);
+  svn_dirent_split(&merge_dirpath, &merge_filename, target_abspath, pool);
 
   /* Give the conflict resolution callback a chance to clean
      up the conflict before we mark the file 'conflicted' */

Modified: subversion/trunk/subversion/libsvn_wc/node.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/node.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/node.c (original)
+++ subversion/trunk/subversion/libsvn_wc/node.c Mon Jun 28 12:45:39 2010
@@ -363,7 +363,7 @@ svn_wc__internal_node_get_url(const char
         {
           const char *parent_abspath;
 
-          svn_dirent_split(local_abspath, &parent_abspath, &repos_relpath,
+          svn_dirent_split(&parent_abspath, &repos_relpath, local_abspath,
                            scratch_pool);
           SVN_ERR(svn_wc__internal_node_get_url(&repos_root_url, db,
                                                 parent_abspath,
@@ -442,7 +442,7 @@ svn_wc__node_get_repos_relpath(const cha
         {
           const char *parent_abspath;
 
-          svn_dirent_split(local_abspath, &parent_abspath, repos_relpath,
+          svn_dirent_split(&parent_abspath, repos_relpath, local_abspath,
                            scratch_pool);
           SVN_ERR(svn_wc__node_get_repos_relpath(repos_relpath, wc_ctx,
                                                  parent_abspath,
@@ -523,7 +523,7 @@ svn_wc__node_get_copyfrom_info(const cha
           const char *base_name;
           const char *parent_copyfrom_url;
 
-          svn_dirent_split(local_abspath, &parent_abspath, &base_name,
+          svn_dirent_split(&parent_abspath, &base_name, local_abspath,
                            scratch_pool);
 
           /* This is a copied node, so we should never fall off the top of a

Modified: subversion/trunk/subversion/libsvn_wc/old-and-busted.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/old-and-busted.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/old-and-busted.c (original)
+++ subversion/trunk/subversion/libsvn_wc/old-and-busted.c Mon Jun 28 12:45:39 2010
@@ -1307,7 +1307,7 @@ svn_wc_entry(const svn_wc_entry_t **entr
 
       const char *dir_abspath;
 
-      svn_dirent_split(local_abspath, &dir_abspath, &entry_name, pool);
+      svn_dirent_split(&dir_abspath, &entry_name, local_abspath, pool);
 
       dir_access = svn_wc__adm_retrieve_internal2(db, dir_abspath, pool);
     }

Modified: subversion/trunk/subversion/libsvn_wc/props.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/props.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/props.c (original)
+++ subversion/trunk/subversion/libsvn_wc/props.c Mon Jun 28 12:45:39 2010
@@ -1961,7 +1961,7 @@ svn_wc__merge_props(svn_wc_notify_state_
               reject_filename = SVN_WC__THIS_DIR_PREJ;
             }
           else
-            svn_dirent_split(local_abspath, &reject_dirpath, &reject_filename,
+            svn_dirent_split(&reject_dirpath, &reject_filename, local_abspath,
                              scratch_pool);
 
           SVN_ERR(svn_io_open_uniquely_named(NULL, &reject_path,

Modified: subversion/trunk/subversion/libsvn_wc/update_editor.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/update_editor.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/update_editor.c (original)
+++ subversion/trunk/subversion/libsvn_wc/update_editor.c Mon Jun 28 12:45:39 2010
@@ -5925,7 +5925,7 @@ svn_wc__check_wc_root(svn_boolean_t *wc_
   if (!*wc_root && switched == NULL )
     return SVN_NO_ERROR; /* No more info needed */
 
-  svn_dirent_split(local_abspath, &parent_abspath, &name, scratch_pool);
+  svn_dirent_split(&parent_abspath, &name, local_abspath, scratch_pool);
 
   /* Check if the node is recorded in the parent */
   if (*wc_root)
@@ -6052,7 +6052,7 @@ svn_wc_get_actual_target2(const char **a
   /* If PATH is not a WC root, or if it is a file, lop off a basename. */
   if (!(is_wc_root || is_switched) || (kind != svn_wc__db_kind_dir))
     {
-      svn_dirent_split(path, anchor, target, result_pool);
+      svn_dirent_split(anchor, target, path, result_pool);
     }
   else
     {

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.c Mon Jun 28 12:45:39 2010
@@ -472,7 +472,7 @@ scan_upwards_for_repos(apr_int64_t *repo
 
       /* Strip a path segment off the end, and append it to the suffix
          that we'll use when we finally find a base relpath.  */
-      svn_relpath_split(current_relpath, &current_relpath, &current_basename,
+      svn_relpath_split(&current_relpath, &current_basename, current_relpath,
                         scratch_pool);
       relpath_suffix = svn_relpath_join(relpath_suffix, current_basename,
                                         scratch_pool);
@@ -2587,7 +2587,7 @@ get_info_for_copy(apr_int64_t *copyfrom_
       svn_wc__db_kind_t parent_kind;
       svn_boolean_t parent_have_work;
 
-      svn_dirent_split(local_abspath, &parent_abspath, &base_name,
+      svn_dirent_split(&parent_abspath, &base_name, local_abspath,
                        scratch_pool);
       SVN_ERR(get_info_for_copy(copyfrom_id, copyfrom_relpath, copyfrom_rev,
                                 &parent_status, &parent_kind, &parent_have_work,
@@ -4070,7 +4070,7 @@ is_add_or_root_of_copy(svn_boolean_t *ad
       svn_revnum_t parent_original_revision;
       svn_error_t *err;
 
-      svn_dirent_split(local_abspath, &parent_abspath, &name, scratch_pool);
+      svn_dirent_split(&parent_abspath, &name, local_abspath, scratch_pool);
 
       err = svn_wc__db_scan_addition(&parent_status,
                                      NULL, NULL, NULL, NULL,
@@ -6811,7 +6811,7 @@ svn_wc__db_temp_is_dir_deleted(svn_boole
   SVN_ERR_ASSERT(not_present != NULL);
   SVN_ERR_ASSERT(base_revision != NULL);
 
-  svn_dirent_split(local_dir_abspath, &parent_abspath, &base_name,
+  svn_dirent_split(&parent_abspath, &base_name, local_dir_abspath,
                    scratch_pool);
 
   /* The parent should be a working copy if this function is called.
@@ -7978,7 +7978,7 @@ svn_wc__db_temp_elide_copyfrom(svn_wc__d
 
   /* If this node is copied/moved, then there MUST be a parent. The above
      copyfrom values cannot be set on a wcroot.  */
-  svn_dirent_split(local_abspath, &parent_abspath, &name, scratch_pool);
+  svn_dirent_split(&parent_abspath, &name, local_abspath, scratch_pool);
   err = svn_wc__db_scan_addition(NULL, &op_root_abspath, NULL, NULL, NULL,
                                  &parent_repos_relpath,
                                  NULL,
@@ -8094,7 +8094,7 @@ svn_wc__db_temp_remove_subdir_record(svn
 
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath));
 
-  svn_dirent_split(local_abspath, &parent_abspath, &name, scratch_pool);
+  svn_dirent_split(&parent_abspath, &name, local_abspath, scratch_pool);
 
   SVN_ERR(svn_wc__db_pdh_parse_local_abspath(&pdh, &local_relpath, db,
                               local_abspath, svn_sqlite__mode_readwrite,
@@ -8356,7 +8356,7 @@ svn_wc__db_temp_set_parent_stub_to_norma
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath)
                  && !svn_dirent_is_root(local_abspath, strlen(local_abspath)));
 
-  svn_dirent_split(local_abspath, &parent_abspath, &base, scratch_pool);
+  svn_dirent_split(&parent_abspath, &base, local_abspath, scratch_pool);
 
   SVN_ERR_ASSERT(*base != '\0');
 

Modified: subversion/trunk/subversion/libsvn_wc/wc_db_pdh.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db_pdh.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/wc_db_pdh.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db_pdh.c Mon Jun 28 12:45:39 2010
@@ -423,7 +423,7 @@ svn_wc__db_pdh_parse_local_abspath(svn_w
          For both of these cases, strip the basename off of the path and
          move up one level. Keep record of what we strip, though, since
          we'll need it later to construct local_relpath.  */
-      svn_dirent_split(local_abspath, &local_abspath, &build_relpath,
+      svn_dirent_split(&local_abspath, &build_relpath, local_abspath,
                        scratch_pool);
 
       /* ### if *pdh != NULL (from further above), then there is (quite

Modified: subversion/trunk/subversion/mod_dav_svn/repos.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/mod_dav_svn/repos.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/util.c (original)
+++ subversion/trunk/subversion/svn/util.c Mon Jun 28 12:45:39 2010
@@ -167,7 +167,7 @@ svn_cl__edit_file_externally(const char 
   int sys_err;
   apr_status_t apr_err;
 
-  svn_dirent_split(path, &base_dir, &file_name, pool);
+  svn_dirent_split(&base_dir, &file_name, path, pool);
 
   SVN_ERR(find_editor_binary(&editor, editor_cmd, config));
 

Modified: subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c (original)
+++ subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c Mon Jun 28 12:45:39 2010
@@ -1345,7 +1345,7 @@ test_dirent_split(apr_pool_t *pool)
     {
       const char *dir, *base_name;
 
-      svn_dirent_split(paths[i][0], &dir, &base_name, pool);
+      svn_dirent_split(&dir, &base_name, paths[i][0], pool);
       if (strcmp(dir, paths[i][1]))
         {
           return svn_error_createf
@@ -1380,7 +1380,7 @@ test_relpath_split(apr_pool_t *pool)
     {
       const char *dir, *base_name;
 
-      svn_relpath_split(paths[i][0], &dir, &base_name, pool);
+      svn_relpath_split( &dir, &base_name, paths[i][0], pool);
       if (strcmp(dir, paths[i][1]))
         {
           return svn_error_createf
@@ -1419,7 +1419,7 @@ test_uri_split(apr_pool_t *pool)
     {
       const char *dir, *base_name;
 
-      svn_uri_split(paths[i][0], &dir, &base_name, pool);
+      svn_uri_split(&dir, &base_name, paths[i][0], pool);
       if (strcmp(dir, paths[i][1]))
         {
           return svn_error_createf



Re: svn commit: r958559 - in /subversion/trunk/subversion: include/ libsvn_client/ libsvn_delta/ libsvn_subr/ libsvn_wc/ mod_dav_svn/ svn/ tests/libsvn_subr/

Posted by Blair Zajac <bl...@orcaware.com>.
On 06/28/2010 05:45 AM, rhuijben@apache.org wrote:
> Author: rhuijben
> Date: Mon Jun 28 12:45:39 2010
> New Revision: 958559
>
> URL: http://svn.apache.org/viewvc?rev=958559&view=rev
> Log:
> Switch the argument order of (the new in 1.7) svn_dirent_split(),
> svn_uri_split() and svn_relpath_split() functions to our new standard
> order: output arguments before input arguments.


> Modified: subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c
> URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c?rev=958559&r1=958558&r2=958559&view=diff
> ==============================================================================
> --- subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c (original)
> +++ subversion/trunk/subversion/tests/libsvn_subr/dirent_uri-test.c Mon Jun 28 12:45:39 2010
...
> @@ -1380,7 +1380,7 @@ test_relpath_split(apr_pool_t *pool)
>       {
>         const char *dir, *base_name;
>
> -      svn_relpath_split(paths[i][0],&dir,&base_name, pool);
> +      svn_relpath_split( &dir,&base_name, paths[i][0], pool);

A whitespace snuck in here.

Regards,
Blair
--- subversion/trunk/subversion/mod_dav_svn/repos.c (original)
+++ subversion/trunk/subversion/mod_dav_svn/repos.c Mon Jun 28 12:45:39 2010
@@ -2293,19 +2293,18 @@ static const char *
 get_parent_path(const char *path, apr_pool_t *pool)
 {
   apr_size_t len;
-  const char *parentpath, *base_name;
+  const char *parentpath;
   char *tmp = apr_pstrdup(pool, path);
 
   len = strlen(tmp);
 
   if (len > 0)
     {
       /* Remove any trailing slash; else svn_uri_split() asserts. */
       if (tmp[len-1] == '/')
         tmp[len-1] = '\0';
-      svn_uri_split(tmp, &parentpath, &base_name, pool);
 
-      return parentpath;
+      return svn_uri_dirname(tmp, pool);
     }
 
   return path;
@@ -2293,19 +2293,18 @@ static const char *
   if (len > 0)
     {
-      /* Remove any trailing slash; else svn_uri_split() asserts. */
+      /* Remove any trailing slash; else svn_uri_dirname() asserts. */
       if (tmp[len-1] == '/')
         tmp[len-1] = '\0';

Modified: subversion/trunk/subversion/svn/util.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/util.c?rev=958559&r1=958558&r2=958559&view=diff
==============================================================================